@@ -16,6 +16,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+"""
+[PoC]Uniform Airflow using live migration
+
+*Description*
+
+It is a migration strategy based on the airflow of physical
+servers. It generates solutions to move VM whenever a server's
+airflow is higher than the specified threshold.
+
+*Requirements*
+
+* Hardware: compute node with NodeManager 3.0 support
+* Software: Ceilometer component ceilometer-agent-compute running
+  in each compute node, and Ceilometer API can report such telemetry
+  "airflow, system power, inlet temperature" successfully.
+* You must have at least 2 physical compute nodes to run this strategy
+
+*Limitations*
+
+- This is a proof of concept that is not meant to be used in production.
+- We cannot forecast how many servers should be migrated. This is the
+  reason why we only plan a single virtual machine migration at a time.
+  So it's better to use this algorithm with `CONTINUOUS` audits.
+- It assumes that live migrations are possible.
+"""
+
+
 from oslo_log import log
 
 from watcher._i18n import _, _LE, _LI, _LW
@@ -293,6 +320,9 @@ class UniformAirflow(base.BaseStrategy):
         if not self.compute_model:
             raise wexc.ClusterStateNotDefined()
 
+        if self.compute_model.stale:
+            raise wexc.ClusterStateStale()
+
         LOG.debug(self.compute_model.to_string())
 
     def do_execute(self):
