@@ -26,10 +26,8 @@ from watcher.decision_engine.model import element
 from watcher.decision_engine.model import model_root
 from watcher.decision_engine.strategy import strategies
 from watcher.tests import base
-from watcher.tests.decision_engine.strategy.strategies \
-    import faker_cluster_state
-from watcher.tests.decision_engine.strategy.strategies \
-    import faker_metrics_collector
+from watcher.tests.decision_engine.model import faker_cluster_state
+from watcher.tests.decision_engine.model import faker_metrics_collector
 
 
 class TestUniformAirflow(base.TestCase):
@@ -53,6 +51,15 @@ class TestUniformAirflow(base.TestCase):
         self.m_ceilometer = p_ceilometer.start()
         self.addCleanup(p_ceilometer.stop)
 
+        p_audit_scope = mock.patch.object(
+            strategies.UniformAirflow, "audit_scope",
+            new_callable=mock.PropertyMock
+        )
+        self.m_audit_scope = p_audit_scope.start()
+        self.addCleanup(p_audit_scope.stop)
+
+        self.m_audit_scope.return_value = mock.Mock()
+
         self.m_model.return_value = model_root.ModelRoot()
         self.m_ceilometer.return_value = mock.Mock(
             statistic_aggregation=self.fake_metrics.mock_get_statistics)
@@ -70,10 +77,10 @@ class TestUniformAirflow(base.TestCase):
     def test_calc_used_res(self):
         model = self.fake_cluster.generate_scenario_7_with_2_nodes()
         self.m_model.return_value = model
-        node = model.get_node_from_id('Node_0')
-        cap_cores = model.get_resource_from_id(element.ResourceType.cpu_cores)
-        cap_mem = model.get_resource_from_id(element.ResourceType.memory)
-        cap_disk = model.get_resource_from_id(element.ResourceType.disk)
+        node = model.get_node_by_uuid('Node_0')
+        cap_cores = model.get_resource_by_uuid(element.ResourceType.cpu_cores)
+        cap_mem = model.get_resource_by_uuid(element.ResourceType.memory)
+        cap_disk = model.get_resource_by_uuid(element.ResourceType.disk)
         cores_used, mem_used, disk_used = self.\
             strategy.calculate_used_resource(
                 node, cap_cores, cap_mem, cap_disk)
